;Mp3 to Ogg Vorbis Converter
;Author: The Kandie Man
Global $version = "0.0.3.1"

;Definitions needed from file.au3================================================================================================{
#cs
#include <File.au3>
#ce
; ===================================================================
; Author: Jason Boggs <vampirevalik AT hotmail DOT com
;
; _PathSplit($szPath, ByRef $szDrive, ByRef $szDir, ByRef $szFName, ByRef $szExt)
;
; Splits a path into the drive, directory, file name and file extension parts.  An empty string is set if a
;	part is missing.
; Parameters:
;	$szPath - IN - The path to be split (Can contain a UNC server or drive letter)
;	$szDrive - OUT - String to hold the drive
; 	$szDir - OUT - String to hold the directory
; 	$szFName - OUT - String to hold the file name
; 	$szExt - OUT - String to hold the file extension
; Returns:
;	Array with 5 elements where 0 = original path, 1 = drive, 2 = directory, 3 = filename, 4 = extension
; ===================================================================
Func _PathSplit($szPath, ByRef $szDrive, ByRef $szDir, ByRef $szFName, ByRef $szExt)
	; Set local strings to null (We use local strings in case one of the arguments is the same variable)
	Local $drive = ""
	Local $dir = ""
	Local $fname = ""
	Local $ext = ""
	Local $i, $pos; For Opt("MustDeclareVars", 1)
	
	; Create an array which will be filled and returned later
	Local $array[5]
	$array[0] = $szPath; $szPath can get destroyed, so it needs set now
	
	; Get drive letter if present (Can be a UNC server)
	If StringMid($szPath, 2, 1) = ":" Then
		$drive = StringLeft($szPath, 2)
		$szPath = StringTrimLeft($szPath, 2)
	ElseIf StringLeft($szPath, 2) = "\\" Then
		$szPath = StringTrimLeft($szPath, 2) ; Trim the \\
		$pos = StringInStr($szPath, "\")
		If $pos = 0 Then $pos = StringInStr($szPath, "/")
		If $pos = 0 Then
			$drive = "\\" & $szPath; Prepend the \\ we stripped earlier
			$szPath = ""; Set to null because the whole path was just the UNC server name
		Else
			$drive = "\\" & StringLeft($szPath, $pos - 1) ; Prepend the \\ we stripped earlier
			$szPath = StringTrimLeft($szPath, $pos - 1)
		EndIf
	EndIf
	
	; Set the directory and file name if present
	For $i = StringLen($szPath) To 0 Step - 1
		If StringMid($szPath, $i, 1) = "\" Or StringMid($szPath, $i, 1) = "/" Then
			$dir = StringLeft($szPath, $i)
			$fname = StringRight($szPath, StringLen($szPath) - $i)
			ExitLoop
		EndIf
	Next
	
	; If $szDir wasn't set, then the whole path must just be a file, so set the filename
	If StringLen($dir) = 0 Then $fname = $szPath
	
	; Check the filename for an extension and set it
	For $i = StringLen($fname) To 0 Step - 1
		If StringMid($fname, $i, 1) = "." Then
			$ext = StringRight($fname, StringLen($fname) - ($i - 1))
			$fname = StringLeft($fname, $i - 1)
			ExitLoop
		EndIf
	Next
	
	; Set the strings and array to what we found
	$szDrive = $drive
	$szDir = $dir
	$szFName = $fname
	$szExt = $ext
	$array[1] = $drive
	$array[2] = $dir
	$array[3] = $fname
	$array[4] = $ext
	Return $array
EndFunc   ;==>_PathSplit
;===============================================================================
;
; Description:      Creates or zero's out the length of the file specified.
; Syntax:           _FileCreate( $sFilePath )
; Parameter(s):     $sFilePath - Path and filename of the file to be created
; Requirement(s):   None
; Return Value(s):  On Success - Returns 1
;                   On Failure - Returns 0 and sets:
;                                @error = 1: Error opening specified file
;                                @error = 2: File could not be written to
; Author(s):        Brian Keene <brian_keene at yahoo dot com>
; Note(s):          None
;
;===============================================================================
Func _FileCreate($sFilePath)
	;==============================================
	; Local Constant/Variable Declaration Section
	;==============================================
	Local $hOpenFile
	Local $hWriteFile
	
	$hOpenFile = FileOpen($sFilePath, 2)
	
	If $hOpenFile = -1 Then
		SetError(1)
		Return 0
	EndIf
	
	$hWriteFile = FileWrite($hOpenFile, "")
	
	If $hWriteFile = -1 Then
		SetError(2)
		Return 0
	EndIf
	
	FileClose($hOpenFile)
	Return 1
EndFunc   ;==>_FileCreate


;========================================================================================================
;
; Function Name:    _TempFile([s_DirectoryName],[s_FilePrefix], [s_FileExtension], [i_RandomLength)
; Description:      Generate a name for a temporary file. The file is guaranteed not to already exist.
; Parameter(s):
;     $s_DirectoryName    optional  Name of directory for filename, defaults to @TempDir
;     $s_FilePrefix       optional  File prefixname, defaults to "~"
;     $s_FileExtension    optional  File extenstion, defaults to ".tmp"
;     $i_RandomLength     optional  Number of characters to use to generate a unique name, defaults to 7
; Requirement(s):   None.
; Return Value(s):  Filename of a temporary file which does not exist.
; Author(s):        Dale (Klaatu) Thompson
;                   Hans Harder - Added Optional parameters
; Notes:            None.
;
;========================================================================================================
Func _TempFile($s_DirectoryName = @TempDir, $s_FilePrefix = "~", $s_FileExtension = ".tmp", $i_RandomLength = 7)
	Local $s_TempName
	; Check parameters
	If Not FileExists($s_DirectoryName) Then $s_DirectoryName = @TempDir   ; First reset to default temp dir
	If Not FileExists($s_DirectoryName) Then $s_DirectoryName = @ScriptDir ; Still wrong then set to Scriptdir
	; add trailing \ for directory name
	If StringRight($s_DirectoryName, 1) <> "\" Then $s_DirectoryName = $s_DirectoryName & "\"
	;
	Do
		$s_TempName = ""
		While StringLen($s_TempName) < $i_RandomLength
			$s_TempName = $s_TempName & Chr(Random(97, 122, 1))
		WEnd
		$s_TempName = $s_DirectoryName & $s_FilePrefix & $s_TempName & $s_FileExtension
	Until Not FileExists($s_TempName)
	
	Return ($s_TempName)
EndFunc   ;==>_TempFile


;================================================================================================} ==> file.au3

;Definitions needed from GUIConstants.au3 ================================================================================================{
#cs
#include <GUIConstants.au3>
#ce
; Window Extended Styles
Global Const $WS_EX_ACCEPTFILES			= 0x00000010
Global Const $WS_EX_TOPMOST				= 0x00000008


; Events and messages
Global Const $GUI_EVENT_CLOSE			= -3
Global Const $GUI_EVENT_MINIMIZE		= -4
Global Const $GUI_EVENT_RESTORE			= -5
Global Const $GUI_EVENT_DROPPED			= -13

; Edit/Input
Global Const $ES_CENTER				= 1
Global Const $ES_MULTILINE			= 4
Global Const $ES_AUTOHSCROLL		= 128
Global Const $ES_READONLY			= 2048

; Progress bar
Global Const $PBS_SMOOTH	= 1


; Combo
Global Const $CBS_DROPDOWNLIST		= 0x0003

; Window Styles
Global Const $WS_VSCROLL			= 0x00200000
Global Const $WS_MINIMIZEBOX		= 0x00020000
Global Const $WS_CAPTION			= 0x00C00000
Global Const $WS_POPUP				= 0x80000000
Global Const $WS_SYSMENU			= 0x00080000


; State
Global Const $GUI_CHECKED		= 1
Global Const $GUI_UNCHECKED		= 4

Global Const $GUI_DROPACCEPTED	= 8

Global Const $GUI_SHOW			= 16
Global Const $GUI_HIDE 			= 32
Global Const $GUI_ENABLE		= 64
Global Const $GUI_DISABLE		= 128

Global Const $GUI_DEFBUTTON		= 512

; Control default styles
Global Const $GUI_SS_DEFAULT_GUI		= BitOR($WS_MINIMIZEBOX, $WS_CAPTION, $WS_POPUP, $WS_SYSMENU)

;================================================================================================} ==> GUIConstants.au3


;Definitions needed from Constants.au3 ================================================================================================{
#cs
#include <Constants.au3>
#ce
Global Const $STDIN_CHILD	= 1
Global Const $STDOUT_CHILD	= 2
Global Const $STDERR_CHILD	= 4

;================================================================================================} ==> constants.au3

;~ #include <array.au3>

#NoTrayIcon
Opt("GUIOnEventMode", 1)
Opt("RunErrorsFatal", 0)
Global $timestamp = TimerInit()
Global $imageindexcounter = 1
Global $filename
Global $filenames
Global $forcount
Global $splitpath[5]
Global $tempwavefile
Global $systemreport = @ScriptDir & "\resource\report.htm"
Global $progress, $lamepicture, $progresslabel, $oggpicture
Global $strlamepic[8]
Global $stroggpic[12]
Global $mp3qualitycombo
Global $mp3qualitylabel
Global $mp3bitratecombo
Global $oggvorbisqualityinput
Global $mp3samplingratecombo
Global $readmp3bitratecombo
Global $oggstandardqualityradio
Global $inilocation = @ScriptDir & "\settings.ini"
Global $encodingcancelled = False
Global $overwritecheckbox
Global $paused = False
Global $main
If Not FileExists($inilocation) Then
	GetSystemInfo()
EndIf
For $i = 0 To 7
	If FileExists(@TempDir & "\resources\lame" & $i + 1 & ".bmp") Then
		$strlamepic[$i] = @TempDir & "\resources\lame" & $i + 1 & ".bmp"
	ElseIf FileExists("lame" & $i + 1 & ".bmp") Then
		$strlamepic[$i] = "lame" & $i + 1 & ".bmp"
	ElseIf FileExists(@ScriptDir & "\resource\lame" & $i + 1 & ".bmp") Then
		$strlamepic[$i] = @ScriptDir & "\resource\lame" & $i + 1 & ".bmp"
	Else
		$strlamepic[$i] = ""
	EndIf
Next
For $i = 0 To 11
	If FileExists(@TempDir & "\resources\twirlfish" & $i + 1 & ".bmp") Then
		$stroggpic[$i] = @TempDir & "\resources\twirlfish" & $i + 1 & ".bmp"
	ElseIf FileExists("twirlfish" & $i + 1 & ".bmp") Then
		$stroggpic[$i] = "twirlfish" & $i + 1 & ".bmp"
	ElseIf FileExists(@ScriptDir & "\resource\twirlfish" & $i + 1 & ".bmp") Then
		$stroggpic[$i] = @ScriptDir & "\resource\twirlfish" & $i + 1 & ".bmp"
	Else
		$stroggpic[$i] = ""
	EndIf
Next
$main = GUICreate("MP3 <-> Ogg Vorbis Converter", 400, 320, -1, -1, -1, $WS_EX_ACCEPTFILES)
GUISetOnEvent($GUI_EVENT_CLOSE, "SpecialEvents")
GUISetOnEvent($GUI_EVENT_MINIMIZE, "SpecialEvents")
GUISetOnEvent($GUI_EVENT_RESTORE, "SpecialEvents")
GUISetOnEvent($GUI_EVENT_DROPPED, "GetDroppedItem")
;lame-encoder GUI postion{
$lameleft = 332
$lametop = 10
$lamewidth = 63
$lameheight = 63
;}
;ogg-encoder GUI Position {
$oggleft = 317
$oggtop = 145
$oggwidth = 63
$oggheight = 63
;}
$lameinput = GUICtrlCreateInput("Drop Files Here", $lameleft - 20, $lametop + 65, $lamewidth + 25, 50, $ES_CENTER + $ES_AUTOHSCROLL + $ES_READONLY + $ES_MULTILINE)
$lamepicture = GUICtrlCreatePic($strlamepic[0], $lameleft - 7, $lametop, $lamewidth, $lameheight, -1);, $WS_EX_ACCEPTFILES)
$ogginput = GUICtrlCreateInput("Drop Files Here", $oggleft - 5, $oggtop + 65, $oggwidth + 25, 50, $ES_CENTER + $ES_AUTOHSCROLL + $ES_READONLY + $ES_MULTILINE)
$oggpicture = GUICtrlCreatePic($stroggpic[0], $oggleft + 7, $oggtop, $oggwidth, $oggheight, -1)
;~ $progress = GUICtrlCreateProgress(10, 280, 380, 15, $PBS_SMOOTH)
$progress = GUICtrlCreateProgress(10, 300, 380, 15, $PBS_SMOOTH)
;~ $progresslabel = GUICtrlCreateLabel("", 10, 260, 200, 20)
$progresslabel = GUICtrlCreateLabel("", 10, 280, 200, 20)
;~ $disableprogcheckbox = GUICtrlCreateCheckbox("Disable Progress/Status Bar (Faster)", 205, 260, 200, 20)
$disableprogcheckbox = GUICtrlCreateCheckbox("Disable Progress/Status Bar (Faster)", 205, 280, 200, 20)
$fileprogresslabel = GUICtrlCreateLabel("", 10, 262, 380, 20)
GUICtrlCreateGroup("MP3 Settings", 0, 0, 310, 135)
;GUICtrlCreateGroup("Ogg Vorbis Settings", 0, 138, 310, 122)
GUICtrlCreateGroup("Ogg Vorbis Settings", 0, 138, 170, 122)
$mp3qualityradio = GUICtrlCreateRadio("Quality", 5, 15, 50, 18)
$mp3bitrateradio = GUICtrlCreateRadio("Bitrate", 135, 15, 50, 18)
GUICtrlCreateGroup("Settings", 5, 30, 130, 100)
GUICtrlCreateGroup("Settings", 135, 30, 167, 65)
GUICtrlCreateLabel("Quality:", 10, 50, 80, 20)
$mp3qualitycombo = GUICtrlCreateCombo("", 50, 45, 80, 20, $CBS_DROPDOWNLIST)
GUICtrlSetData($mp3qualitycombo, "10|20|30|40|50|60|70|80|90|100")
GUICtrlSetData($mp3qualitycombo, "50")
GUICtrlSetOnEvent($mp3qualitycombo, "MP3QualityCombo")
$mp3qualitylabel = GUICtrlCreateLabel("Approx. Bitrate 132 kbps", 10, 70, 118, 20)
GUICtrlCreateLabel("Variable Bitrate Mode:", 10, 90, 120, 20)
$mp3vbrmodecombo = GUICtrlCreateCombo("", 10, 105, 120, 20, $CBS_DROPDOWNLIST)
GUICtrlSetData($mp3vbrmodecombo, "New Method|Old Method(faster?)")
GUICtrlSetData($mp3vbrmodecombo, "New Method")
#cs
	Ogg vorbis bit rate calculation
	qual * 32 = bit rate
#ce
;~ $mp3qualityslider = GUICtrlCreateSlider ( 10, 45 , 180 , 20 ,$TBS_AUTOTICKS)
;~ GUICtrlSetLimit ( $mp3qualityslider, 100 , 0 )
#cs
	$mp3bitratecombo = GUICtrlCreateInput ("128",215,45, 40, 20,$ES_NUMBER)
	GUICtrlSetOnEvent($mp3bitratecombo,"Checkforvalidbitrate")
	$mp3bitrateupdown = GUICtrlCreateUpdown($mp3bitratecombo)
	GUICtrlSetLimit($mp3bitrateupdown,320,0)
	GUICtrlSetLimit($mp3bitratecombo,320,0)
#ce
$mp3bitratecombo = GUICtrlCreateCombo("", 215, 45, 50, 20, $CBS_DROPDOWNLIST + $WS_VSCROLL)
$combostring = 0
For $counter = 1 To 320
	$combostring &= "|" & $counter
Next
GUICtrlSetData($mp3bitratecombo, $combostring)
GUICtrlSetData($mp3bitratecombo, 128)
GUICtrlCreateLabel("Target Bitrate:", 140, 50)
GUICtrlCreateLabel("kbps", 270, 50, 25)
;~ $mp3bitratecombo = GUICtrlCreateCombo("", 215, 45, 50, 20, $CBS_DROPDOWNLIST)
;~ GUICtrlSetData($mp3bitratecombo, "32|40|48|56|64|80|96|112|128|160|192|224|256|320")
;~ GUICtrlSetData($mp3bitratecombo, "128")
$lameconstantbitratecheck = GUICtrlCreateCheckbox("Constant Bitrate (CBR)", 140, 70, 160, 18)
GUICtrlSetOnEvent($lameconstantbitratecheck, "Checkvalidsampletobitrate")
$lamemonoencodingcheck = GUICtrlCreateCheckbox("Mono Encoding", 140, 95, 100, 15)
GUICtrlCreateLabel("Sampling Rate:", 140, 115, 75, 18)
GUICtrlCreateLabel("kHz", 275, 115, -1, 18)
$mp3samplingratecombo = GUICtrlCreateCombo("", 220, 110, 50, 1, $CBS_DROPDOWNLIST)
GUICtrlSetData($mp3samplingratecombo, "8|11.025|12|16|22.05|24|32|44.1|48")
GUICtrlSetData($mp3samplingratecombo, "44.1")
;Ogg Vorbis Quality Controls {
GUICtrlSetOnEvent($mp3samplingratecombo, "Checkvalidsampletobitrate")
$oggstandardqualityradio = GUICtrlCreateRadio("Standard Quality Mode", 5, 150, 130, 18)
GUICtrlSetState($oggstandardqualityradio, $GUI_CHECKED)
GUICtrlCreateGroup("Settings:", 5, 165, 160, 90)
GUICtrlCreateLabel("Quality Setting:", 10, 180, 72, 18)
$oggvorbisqualityinput = GUICtrlCreateInput("6.00", 10, 195, 35, 20, $ES_CENTER)
GUICtrlCreateLabel("Range: -2.00 to 10.00", 48, 200, 110, 18)
$nominalbitratecaption = GUICtrlCreateLabel("Nominal Bitrate 192kbps", 10, 225, 140)
GUICtrlSetOnEvent($oggvorbisqualityinput, "CalculateNominalBitrate")
;~ $stopbutton = GUICtrlCreateButton("Stop Encoding", 316, 126, 80, 17)
$stopbutton = GUICtrlCreateButton("Stop Encoding", 190, 195, 80, 20)
GUICtrlSetState($stopbutton, $GUI_HIDE)
$pausebutton = GUICtrlCreateButton("Pause", 190, 165, 80, 20)
GUICtrlSetState($pausebutton, $GUI_HIDE)
$overwritecheckbox = GUICtrlCreateCheckbox("Overwrite files", 190, 145, 85, 18)
$aboutbutton = GUICtrlCreateButton("About", 190, 195, 80, 20)
GUICtrlSetOnEvent($aboutbutton, "AboutBox")
$ontopcheckbox = GUICtrlCreateCheckbox("Always On Top", 190, 165, 90, 18)
GUICtrlSetOnEvent($ontopcheckbox, "OnTopCheckbox")
;}
;~ GUICtrlCreateCombo("",
;~  32  48  44.1
;~ $input = GUICtrlCreateInput("",20,20,-1,-1,-1);,$WS_EX_ACCEPTFILES)
;set state to accept files
;~ GUICtrlSetState($input, $GUI_DROPACCEPTED)
;~ GUICtrlSetState($lamepicture, $GUI_DROPACCEPTED)
;~ GUICtrlSetState($lamepicture, $GUI_DROPACCEPTED)
GUICtrlSetState($lameinput, $GUI_DROPACCEPTED)
GUICtrlSetState($ogginput, $GUI_DROPACCEPTED)
GUICtrlSetState($disableprogcheckbox, $GUI_CHECKED)
GUICtrlSetState($mp3qualityradio, $GUI_CHECKED)
WinSetTrans($main, "", 0)
GUISetState(@SW_SHOW)
GUICtrlSetState($disableprogcheckbox, $GUI_HIDE)
INIReadSettings()
GUICtrlSetData($progresslabel, "Ready")
If @OSVersion <> "WIN_NT4" And @OSVersion <> "WIN_ME" And @OSVersion <> "WIN_98" And @OSVersion <> "WIN_95" And @OSVersion <> "WIN_6.0" And @OSVersion <> "WIN_6.1" Then
	For $transcount = 0 To 255 Step 3
		WinSetTrans($main, "", $transcount)
		Sleep(1)
	Next
EndIf
While 1
	Sleep(10)
WEnd
Func GetDroppedItem()
	DisableControls()
	$encodingcancelled = False
	$paused = False
	If $lameinput = @GUI_DropId Then
		$readlameinput = GUICtrlRead($lameinput)
	ElseIf $ogginput = @GUI_DropId Then
		$readlameinput = GUICtrlRead($ogginput)
	EndIf
;~ 	msgbox(0,@GUI_DropID,$lameinput)
	$multimplemp3drop = StringInStr($readlameinput, "|")
	If $multimplemp3drop Then
		If StringInStr($readlameinput, "Drop Files Here") Then
			$readlameinput = StringReplace($readlameinput, "Drop Files Here", "", 0, 1)
		EndIf
		$filenames = StringSplit($readlameinput, "|")
;~ 		_ArrayDisplay($filenames, "aasd")
	Else
		Dim $filenames[2]
		$filenames[0] = 1
		$filenames[1] = @GUI_DragFile
	EndIf
	GUICtrlSetState($aboutbutton, $GUI_HIDE)
	GUICtrlSetState($overwritecheckbox, $GUI_HIDE)
	GUICtrlSetData($pausebutton, "Pause")
	GUICtrlSetState($stopbutton, $GUI_SHOW)
	GUICtrlSetState($pausebutton, $GUI_SHOW)
	GUICtrlSetPos($ontopcheckbox, 190, 145, 90, 18)
	If $lameinput = @GUI_DropId Then
		GUICtrlSetData($lameinput, "Drop Files Here")
		$forcount = 1
;~ 	Msgbox(0,"ID's",@GUI_DROPID & @GUI_DRAGFILE & @GUI_DRAGID)
		Opt("GUIOnEventMode", 0)
		While $forcount <= $filenames[0]
			If $encodingcancelled = True Then ExitLoop
			If FileExists($filenames[$forcount]) Then
				Dim $szDrive, $szDir, $szFName, $szExt
				$splitpath = _PathSplit($filenames[$forcount], $szDrive, $szDir, $szFName, $szExt)
				$tempwavefile = @TempDir & '\' & $splitpath[3] & '.wav'
				If $splitpath[4] = ".mp3" Or $splitpath[4] = ".ogg" Or $splitpath[4] = ".wav" Then
					Select
						Case $splitpath[4] = ".mp3"
;~ 			Run(@ComSpec & " /c " & 'lame.exe', "", @SW_HIDE)
;~ 			ConsoleWrite('lame.exe --decode "' & $filename & '" "' & @TempDir & '\' & $splitpath[3] & '.wav"')
							If VerifyOverwrite($splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav") = True Then
								Mp3Decode()
;~ 							If VerifyOverwrite($splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav") = True Then
								If $encodingcancelled = False Then
									FileMove($tempwavefile, $splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav")
								Else
									FileDelete($tempwavefile)
								EndIf
							EndIf
						Case $splitpath[4] = ".ogg"
							If VerifyOverwrite($splitpath[1] & $splitpath[2] & $splitpath[3] & ".mp3") = True Then
;~ 								If FileExists Then($splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav" Then
;~ 									$movedsucessfully = FileMove($splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav",$splitpath[1] & $splitpath[2] &  "\original wav\" & $splitpath[3] & ".wav",8)
;~ 										If $movedsucessfully = 0 Then
;~ 											Msgbox(0,"Error!","You have a wav file in your current directory with the same name.  This causes problems since the temporary wav file must be written in that directory with the samem name
;~ 										EndIf
;~ 								Endif
								OggDecode()
								Convert_to_mp3($tempwavefile, $splitpath[1] & $splitpath[2] & $splitpath[3], $splitpath[4])
								If $encodingcancelled = True Then FileDelete($splitpath[1] & $splitpath[2] & $splitpath[3] & ".mp3")
							EndIf
							FileDelete($tempwavefile)
						Case $splitpath[4] = ".wav"
							If VerifyOverwrite($splitpath[1] & $splitpath[2] & $splitpath[3] & ".mp3") = True Then
								FileCopy($filenames[$forcount], $tempwavefile, 1)
;~ 			MsgBox(48,"Error!","WAV")
								Convert_to_mp3($tempwavefile, $splitpath[1] & $splitpath[2] & $splitpath[3], $splitpath[4])
							EndIf
							If $encodingcancelled = True Then FileDelete($splitpath[1] & $splitpath[2] & $splitpath[3] & ".mp3")
							FileDelete($tempwavefile)
					EndSelect
				Else
					MsgBox(48, "Error!", "Invalid File Type.")
				EndIf
			Else
				MsgBox(48, "Error!", "File could not be found.")
			EndIf
			$forcount = $forcount + 1
		WEnd
	ElseIf @GUI_DropId = $ogginput Then
		GUICtrlSetData($ogginput, "Drop Files Here")
		$forcount = 1
;~ 	Msgbox(0,"ID's",@GUI_DROPID & @GUI_DRAGFILE & @GUI_DRAGID)
		Opt("GUIOnEventMode", 0)
		While $forcount <= $filenames[0]
			If $encodingcancelled = True Then ExitLoop
			ConsoleWrite($filenames[$forcount] & @CR)
			If FileExists($filenames[$forcount]) Then
				Dim $szDrive, $szDir, $szFName, $szExt
				$splitpath = _PathSplit($filenames[$forcount], $szDrive, $szDir, $szFName, $szExt)
				$tempwavefile = @TempDir & '\' & $splitpath[3] & '.wav'
				If $splitpath[4] = ".mp3" Or $splitpath[4] = ".ogg" Or $splitpath[4] = ".wav" Then
					Select
						Case $splitpath[4] = ".mp3"
;~ 			Run(@ComSpec & " /c " & 'lame.exe', "", @SW_HIDE)
;~ 			ConsoleWrite('lame.exe --decode "' & $filename & '" "' & @TempDir & '\' & $splitpath[3] & '.wav"')
							If VerifyOverwrite($splitpath[1] & $splitpath[2] & $splitpath[3] & ".ogg") = True Then
								Mp3Decode()
								OggEncode($tempwavefile, $splitpath[1] & $splitpath[2] & $splitpath[3], $splitpath[4])
								FileMove(@TempDir & "\" & $splitpath[3] & '.ogg', $splitpath[1] & $splitpath[2] & $splitpath[3] & ".ogg", 1)
								OGGTagin($tempwavefile, $splitpath[1] & $splitpath[2] & $splitpath[3], $splitpath[4])
							EndIf
							FileDelete($tempwavefile)
						Case $splitpath[4] = ".ogg"
							If VerifyOverwrite($splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav") = True Then
								OggDecode()
								If $encodingcancelled = False Then
									FileMove($tempwavefile, $splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav", 1)
								Else
									FileDelete($tempwavefile)
								EndIf
							Else
								FileDelete($tempwavefile)
							EndIf
						Case $splitpath[4] = ".wav"
							If VerifyOverwrite($splitpath[1] & $splitpath[2] & $splitpath[3] & ".ogg") = True Then
								FileCopy($filenames[$forcount], $tempwavefile, 1)
								OggEncode($tempwavefile, $splitpath[1] & $splitpath[2] & $splitpath[3], $splitpath[4])
								FileMove(@TempDir & "\" & $splitpath[3] & '.ogg', $splitpath[1] & $splitpath[2] & $splitpath[3] & ".ogg", 1)
							EndIf
							FileDelete($tempwavefile)
					EndSelect
				Else
					MsgBox(48, "Error!", "Invalid File Type.")
				EndIf
			Else
				MsgBox(48, "Error!", "File could not be found.")
			EndIf
			$forcount = $forcount + 1
		WEnd
	EndIf
	Opt("GUIOnEventMode", 1)
	GUICtrlSetPos($ontopcheckbox, 190, 165, 90, 18)
	GUICtrlSetState($overwritecheckbox, $GUI_SHOW)
	GUICtrlSetState($stopbutton, $GUI_HIDE)
	GUICtrlSetState($pausebutton, $GUI_HIDE)
	GUICtrlSetState($aboutbutton, $GUI_SHOW)
	GUICtrlSetData($progresslabel, "Ready")
	GUICtrlSetData($progress, 0)
	EnableControls()
EndFunc   ;==>GetDroppedItem
Func Mp3Decode()
	$progresscheckboxstatus = GUICtrlRead($disableprogcheckbox)
	GUICtrlSetData($fileprogresslabel, "Decoding: " & $splitpath[3] & ".mp3")
	If $progresscheckboxstatus = $GUI_UNCHECKED Then
		$lamepid = Run('lame.exe --decode --brief "' & $filenames[$forcount] & '" "' & @TempDir & '\' & $splitpath[3] & '.wav"', @ScriptDir, @SW_HIDE, $STDERR_CHILD);,$STDIN_CHILD)
	Else
		$lamepid = Run('lame.exe --decode --brief "' & $filenames[$forcount] & '" "' & @TempDir & '\' & $splitpath[3] & '.wav"', @ScriptDir, @SW_HIDE)
		GUICtrlSetData($progresslabel, "Decoding...")
	EndIf
;~ 		msgbox(0,$forcount,'lame.exe --decode --brief "' & $filenames[$forcount] & '" "' & @TempDir & '\' & $splitpath[3] & '.wav"')
	ProcessSetPriority($lamepid, 0)
	$timestamp = TimerInit()
	Dim $imageindexcounter = 1
;~ 			$handle = FileOpen("log.txt",2)
	While ProcessExists($lamepid)
		If $progresscheckboxstatus = $GUI_UNCHECKED And $paused = False Then
			$readstream = StderrRead($lamepid)
			$splitstring = StringSplit($readstream, @CR)
;~ 				_arrayDisplay($splitstring ,"asdf")
;~ 				Msgbox(0,"",$readstream)
;~ 				FileWrite($handle ,$readstream)
			#cs
				If @error Then
				ProcessClose($lamepid)
				ConsoleWrite(@CRLF & "array could not be formed.")
				Exit
				EndIf
			#ce
;~ 			Msgbox(0,"asdf",$splitstring[2])
			If UBound($splitstring) > 3 Then
;~ 				Msgbox(0,"uboundwokrs",Stringleft($splitstring [2],6))
				If StringLeft($splitstring [2], 6) = "Frame#" Then
;~ 					ConsoleWrite($splitstring[2] & @CR)
					$trimmed = StringStripWS(StringTrimLeft($splitstring[2], 6), 1)
					$position = StringInStr($trimmed, " ")
					$bitratediv = StringLeft($trimmed, $position)
					If Int( Execute($bitratediv) * 100) <= 100 Then
						GUICtrlSetData($progresslabel, Int( Execute($bitratediv) * 100) & "% done.")
						GUICtrlSetData($progress, Int( Execute($bitratediv) * 100))
						WinSetTitle($main, "", Int( Execute($bitratediv) * 100) & "% done.")
					EndIf
				EndIf
			EndIf
		EndIf
;~ 			GUICtrlSetData($progresslabel,StderrRead ( $lamepid ))
;~ 			GUICtrlSetData($progresslabel,Int(Number ( $splitstring[2] )*100) & "% done.")
;~ 			GUICtrlSetData($progress,Int(Number ( $splitstring[2] )*100))
		If $paused = False Then SpinLameImage()
;~ 		Sleep(10)
		$msg = GUIGetMsg()
		Select
			Case $msg = $stopbutton
				$encodingcancelled = True
				ProcessClose($lamepid)
				FileDelete($tempwavefile)
			Case $msg = $pausebutton
;~ 				PauseEncoding()
				If $paused = False Then
					GUICtrlSetData($pausebutton, "Resume")
					$paused = True
				Else
					GUICtrlSetData($pausebutton, "Pause")
					$paused = False
				EndIf
			Case $msg = $ontopcheckbox
				OnTopCheckbox()
			Case $msg = $GUI_EVENT_CLOSE
				$encodingcancelled = True
				ProcessClose($lamepid)
				FileDelete($tempwavefile)
				Terminate()
		EndSelect
	WEnd
	WinSetTitle($main, "", "MP3 <-> Ogg Vorbis Converter")
	GUICtrlSetData($progresslabel, 100 & "% done.")
	GUICtrlSetData($progress, 100)
;~ 			FileClose($handle)
	GUICtrlSetData($fileprogresslabel, "")
	GUICtrlSetImage($lamepicture, $strlamepic[0])
	GUICtrlSetData($progresslabel, "Ready")
	GUICtrlSetData($progress, 0)
EndFunc   ;==>Mp3Decode
Func SpecialEvents()
;~ 	msgbox(0,"","special event triggered")
	Select
		Case @GUI_CtrlId = $GUI_EVENT_CLOSE
;~             MsgBox(0, "Close Pressed", "ID=" & @GUI_CTRLID & " WinHandle=" & @GUI_WINHANDLE)
;~ 				If @OSVersion = "WIN_2003" or @OSVersion = "WIN_XP" or @OSVersion = "WIN_2000" Then
			If @OSVersion <> "WIN_NT4" And @OSVersion <> "WIN_ME" And @OSVersion <> "WIN_98" And @OSVersion <> "WIN_95" And @OSVersion <> "WIN_6.0" And @OSVersion <> "WIN_6.1" Then
				For $transcount = 255 To 0 Step - 1
					WinSetTrans($main, "", $transcount)
				Next
			EndIf
			WriteINISettings()
			Exit
		Case @GUI_CtrlId = $GUI_EVENT_MINIMIZE
;~             MsgBox(0, "Window Minimized", "ID=" & @GUI_CTRLID & " WinHandle=" & @GUI_WINHANDLE)
		Case @GUI_CtrlId = $GUI_EVENT_RESTORE
;~             MsgBox(0, "Window Restored", "ID=" & @GUI_CTRLID & " WinHandle=" & @GUI_WINHANDLE)
	EndSelect
EndFunc   ;==>SpecialEvents
Func Convert_to_mp3($filein, $fileout, $origextension)
;~ 	GUICTrlSetData($progresslabel, "Encoding MP3...")
	#cs
		CBR (constant bitrate, the default) options:
		-b <bitrate>    set the bitrate in kbps, default 128 kbps
		--cbr           enforce use of constant bitrate
		ABR options:
		--abr <bitrate> specify average bitrate desired (instead of quality)
		VBR options:
		-v              use variable bitrate (VBR) (--vbr-old)
		--vbr-old       use old variable bitrate (VBR) routine
		--vbr-new       use new variable bitrate (VBR) routine
		-V n            quality setting for VBR.  default n=4
		0=high quality,bigger files. 9=smaller files
		-b <bitrate>    specify minimum allowed bitrate, default  32 kbps
		-B <bitrate>    specify maximum allowed bitrate, default 320 kbps
		-F              strictly enforce the -b option, for use with players that
		do not support low bitrate mp3
		-t              disable writing LAME Tag
		-T              enable and force writing LAME Tag
	#ce
;~ 	ConsoleWrite($filein)
;~ Msgbox(0,$GUI_CHECKED,GUICtrlRead($mp3qualityradio))
	If $encodingcancelled = True Then Return 0
	If GUICtrlRead($mp3qualityradio) = $GUI_CHECKED Then
		$readqualitycombo = GUICtrlRead($mp3qualitycombo)
		Select
			Case $readqualitycombo = 10
				$quality = "-V 9"
			Case $readqualitycombo = 20
				$quality = "-V 8"
			Case $readqualitycombo = 30
				$quality = "-V 7"
			Case $readqualitycombo = 40
				$quality = "-V 6"
			Case $readqualitycombo = 50
				$quality = "-V 5"
			Case $readqualitycombo = 60
				$quality = "-V 4"
			Case $readqualitycombo = 70
				$quality = "-V 3"
			Case $readqualitycombo = 80
				$quality = "-V 2"
			Case $readqualitycombo = 90
				$quality = "-V 1"
			Case $readqualitycombo = 100
				$quality = "-V 0"
		EndSelect
		$readmp3vbrmodecombo = GUICtrlRead($mp3vbrmodecombo)
		Select
			Case $readmp3vbrmodecombo = "New Method"
				$qualitymode = "--vbr-new "
			Case $readmp3vbrmodecombo = "Old Method(faster?)"
				$qualitymode = "--vbr-old "
		EndSelect
		$mp3readsamplereate = GUICtrlRead($mp3samplingratecombo)
		$mp3encodingparameters = "--resample " & $mp3readsamplereate & " " & $qualitymode & $quality
	Else
		$readmp3bitrateinput = GUICtrlRead($mp3bitratecombo)
;~ 		Msgbox(0,"Checkbox" ,"Value of read checkbox " & GUICtrlRead($lameconstantbitratecheck) & @CR & "Value of CheckConstant: " & $GUI_CHECKED)
		If GUICtrlRead($lameconstantbitratecheck) = $GUI_CHECKED Then
;~ 			Msgbox(0,"",GUICtrlRead($lameconstantbitratecheck) & " " & $GUI_CHECKED)
			$mp3bitrate = "--preset cbr " & Number($readmp3bitrateinput)
		Else
;~ 			Msgbox(0,"ABR",GUICtrlRead($lameconstantbitratecheck) & " " & $GUI_CHECKED)
			$mp3bitrate = "--abr " & Number($readmp3bitrateinput)
		EndIf
		$mp3readsamplereate = GUICtrlRead($mp3samplingratecombo)
		$mp3encodingparameters = "--resample " & $mp3readsamplereate & " " & $mp3bitrate
	EndIf
	If GUICtrlRead($lamemonoencodingcheck) = $GUI_CHECKED Then
		$mp3encodingparameters &= " -a"
	EndIf
	$progresscheckboxstatus = GUICtrlRead($disableprogcheckbox)
;~ 	Msgbox(0,"Command Line",'lame.exe ' & $mp3encodingparameters  & ' "' & $filein & '" "' & $fileout & '.mp3"')
;~ 	$openhandle = FileOpen("lameenc.bat", 2)
;~ 	FileWriteLine($openhandle, 'lame.exe ' & $mp3encodingparameters & ' "' & $filein & '" "' & $fileout & '.mp3"')
;~ 	FileWriteLine($openhandle, "pause")
;~ 	FileClose($openhandle)
	If VerifyOverwrite($fileout & '.mp3') = True Then
		If FileExists($filein) Then
			Local $szDrive, $szDir, $szFName, $szExt
			_PathSplit($filein, $szDrive, $szDir, $szFName, $szExt)
			GUICtrlSetData($fileprogresslabel, "Encoding: " & $szFName & ".mp3"); & $szExt)
			If $progresscheckboxstatus = $GUI_UNCHECKED Then
				$lameencpid = Run('lame.exe ' & $mp3encodingparameters & ' "' & $filein & '" "' & $fileout & '.mp3"', @ScriptDir, @SW_HIDE, $STDERR_CHILD)
			Else
				$lameencpid = Run('lame.exe  ' & $mp3encodingparameters & ' "' & $filein & '" "' & $fileout & '.mp3" ' & $mp3encodingparameters, @ScriptDir, @SW_HIDE)
				GUICtrlSetData($progresslabel, "Encoding...")
			EndIf
			$timestamp = TimerInit()
			$imageindexcounter = 1
;~ 		$handle = FileOpen("log.log",1 )
			$streamcounter = 0
			While ProcessExists($lameencpid)
				If 1 <= $streamcounter And $progresscheckboxstatus = $GUI_UNCHECKED And $paused = False Then
;~ 			If $progresscheckboxstatus = $GUI_UNCHECKED Then
					$readstream = StderrRead($lameencpid);,0,true)
;~ 			$splitarraystream = StringSplit($readstream,@CR)
;~ 			$splitarraystream = StringSplit($readstream,"%)|")
;~ 			_ArrayDisplay($splitarraystream,"SADF")
;~ 				Msgbox(0,"Stream",$readstream)
					$position = StringInStr($readstream, "%)")
					$firsttrim = StringLeft($readstream, $position - 1)
					$position2 = StringInStr($firsttrim, " (")
					$percentdone = StringTrimLeft($firsttrim, $position2 + 1)
;~ 			If Ubound($splitarraystream )>1 Then
;~ 				Msgbox(0,"",'"' & StringStripWS ($splitarraystream[1],1) & '"')
;~ 				$splitstream2 = StringSplit(StringStripWS ($splitarraystream[1],1)," (")
;~ 				_ArrayDisplay($splitstream2,"")
;~ 				If Ubound($splitstream2) > 1 Then
;~ 					Msgbox(0,"",$splitstream2[2])
					If Not StringInStr($percentdone, ":") And Not StringInStr($percentdone, "  ") And Not $percentdone = "" Then
						GUICtrlSetData($progress, $percentdone)
						GUICtrlSetData($progresslabel, $percentdone & "% done encoding MP3...")
						WinSetTitle($main, "", $percentdone & "% done encoding MP3")
					EndIf
					$streamcounter = 0
				EndIf
;~ 				EndIf
;~ 			Endif
;~ 			"%)|"
;~ 			FileWrite($handle,$readstream)
;~ 			msgbox(0,"readstream",$readstream)
				If $paused = False Then SpinLameImage()
;~ 			Sleep(10)
				$msg = GUIGetMsg()
				Select
					Case $msg = $stopbutton
						$encodingcancelled = True
						ProcessClose($lameencpid)
						FileDelete($tempwavefile)
					Case $msg = $pausebutton
						If $paused = False Then
							GUICtrlSetData($pausebutton, "Resume")
							$paused = True
						Else
							GUICtrlSetData($pausebutton, "Pause")
							$paused = False
						EndIf
					Case $msg = $ontopcheckbox
						OnTopCheckbox()
					Case $msg = $GUI_EVENT_CLOSE
						$encodingcancelled = True
						ProcessClose($lameencpid)
						FileDelete($tempwavefile)
						Terminate()
				EndSelect
				$streamcounter = $streamcounter + 1
			WEnd
;~ 		FileClose($handle)
			If FileExists($fileout & ".mp3") Then
				#cs
					When using tag.exe, use the parameter --fromfile <filename>
					The total command should look like this:
					Tag.exe --fromfile <original filname>  filetosendtaginfoto
				#ce
				Run('"' & @ScriptDir & '\resource\ID3\Tag.exe" --fromfile "' & $fileout & $origextension & '" "' & $fileout & '.mp3"', @ScriptDir, @SW_HIDE)
;~ 			Run('"' & @ScriptDir & '\resource\ID3\Tag.exe" --force "ID3v2" --fromfile "' & $fileout & $origextension & '" "' & $fileout & '.mp3"', @ScriptDir, @SW_HIDE)
			Else
				If $encodingcancelled = False Then MsgBox(48, "Error!", "Could not create mp3 file.")
			EndIf
		Else
;~ 		MsgBox(48, "Error!", "The temporary .wav file could not be found.")
		EndIf
	EndIf
	WinSetTitle($main, "", "MP3 <-> Ogg Vorbis Converter")
	GUICtrlSetData($fileprogresslabel, "")
	GUICtrlSetData($progresslabel, "")
	GUICtrlSetImage($lamepicture, $strlamepic[0])
EndFunc   ;==>Convert_to_mp3
Func SpinLameImage()
	If TimerDiff($timestamp) > 100 Then
		GUICtrlSetImage($lamepicture, $strlamepic[$imageindexcounter])
		If $imageindexcounter < 7 Then
			$imageindexcounter = $imageindexcounter + 1
		Else
			$imageindexcounter = 0
		EndIf
		$timestamp = TimerInit()
	EndIf
EndFunc   ;==>SpinLameImage
Func INIWriteComputerinfo($data)
	IniWrite($inilocation, "Computer", "OggEnc", @ScriptDir & "\resource\" & $data & "\oggenc2.exe")
EndFunc   ;==>INIWriteComputerinfo
Func GetSystemInfo()
	SplashTextOn("Initializing...", "MP3 <-> Ogg is checking your hardware.  It should only do this the first time or whenever the settings.ini is deleted.  This should only take a few seconds...", -1, 35, -1, -1, 2 + 16,"Arial",10)
	If FileExists(@ScriptDir & "\resource\cpuz.exe") Then
		$cpuzprocess = Run(@ScriptDir & "\resource\cpuz.exe -html=report", @ScriptDir & "\resource\", @SW_HIDE)
		While ProcessExists($cpuzprocess)
			Sleep(10)
		WEnd
		If Not FileExists($inilocation) Then
			_FileCreate($inilocation)
			$h_inihandle = FileOpen($inilocation, 2)
			FileWrite($h_inihandle, ";Warning!  Please do not edit this file manually.  Editing it with incorrect values can and will cause the program to crash and/or work incorrectly.")
			FileClose($h_inihandle)
		EndIf
;~ 		FileOpen(@ScriptDir & "\resource\report.htm", 0)
;~ 		Dim $readreport
		$spechandle = FileOpen($systemreport, 0)
		$readfile = FileRead($spechandle, FileGetSize($systemreport))
		FileClose($spechandle)
;~ 		$result = StringInStr($readfile,"Pentium")
;~
;~ 		If $result > 0 Then
;~ 			Msgbox(0,"Pentium","A pentium processor has been detected.")
;~ 			$result = StringInStr($readfile,"Pentium 4")
;~ 			If $result > 0 Then
;~ 				Msgbox(0,"Pentium","A pentium 4 processor in specific has been detected.")
;~ 			Else
;~ 				MsgBox(0,"Pentium","Using generic pentium encoders.")
;~ 			EndIf
;~
;~ 		Else
;~ 			$result = StringInStr($readfile,"AMD")
;~
;~ 			If $result >0 Then
;~ 				Msgbox(0,"AMD","An AMD computer has been detected.")
;~ 			Endif
;~ 		Endif
		$result = StringInStr($readfile, "SSE3")
		If $result > 0 Then
			$typefound = False
			For $x = 0 To 9
				For $y = 0 To 9
					$result = StringInStr($readfile, $x & " (" & $y & " Physical")
					If $result > 0 Then
						$typefound = True
						ExitLoop
					EndIf
				Next
				If $typefound = True Then ExitLoop
			Next
			If $typefound = True Then
				;multithreading SSE3
				INIWriteComputerinfo("oggenc283_sse3mt_lancer")
			Else
				;single processor with SSE3
				INIWriteComputerinfo("oggenc283_sse3_lancer")
;~ 					Msgbox(0,"Single Thread","A single processor has been detected that doesn't support multithreading.")
			EndIf
		Elseif	0 < StringInStr($readfile, "SSE2") Then
;~ 				Msgbox(0,"SSE2","SSE2 instruction set detected.")
			$typefound = False
			For $x = 0 To 9
				For $y = 0 To 9
					$result = StringInStr($readfile, $x & " (" & $y & " Physical")
					If $result > 0 Then
;~ 							Msgbox(0,"Multithreading Found","The processor has ")
						$typefound = True
						ExitLoop
					EndIf
				Next
				If $typefound = True Then ExitLoop
			Next
			If $typefound = True Then
				;Multithreading with SSE2
;~ 					Msgbox(0,"Multithreading Found","A multithreading processord with an SSE2 instruction set has been detected.")
				INIWriteComputerinfo("oggenc283_sse2mt_lancer")
			Else
				;Single processor with SSE2
				INIWriteComputerinfo("oggenc283_sse2_lancer")
;~ 					Msgbox(0,"Single Thread","A single processor with SSE2 has been detected that doesn't support multithreading.")
			EndIf
			$readfile = 0
		ElseIf 0 < StringInStr($readfile, "SSE") Then
			INIWriteComputerinfo("oggenc283_sse_lancer")
		Else
			INIWriteComputerinfo("oggenc2.83-aoTuVb4.51generic")
		EndIf
;~ 		_FileReadToArray($systemreport, $readreport)
;~ 		_ArraySort($readreport)
;~ 		_ArrayDisplay($readreport,"title")
;~ 		Msgbox(0,"Pentium", _ArrayBinarySearch($readreport,"Pentium"))
;~ 		Msgbox(0,"AMD Return Value: ", _ArrayBinarySearch($readreport,"AMD"))
;~ 		$readreport = 0
	EndIf
	SplashOff()
EndFunc   ;==>GetSystemInfo
Func OggDecode()
	$progresscheckboxstatus = GUICtrlRead($disableprogcheckbox)
	$decoderexe = @ScriptDir & "\resource\oggdec\oggdec.exe"
;~ If VerifyOverwrite($splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav") = True Then
	GUICtrlSetData($fileprogresslabel, "Decoding: " & $splitpath[3] & ".ogg")
	Local $szDrive, $szDir, $szFName, $szExt
	_PathSplit($filenames[$forcount], $szDrive, $szDir, $szFName, $szExt)
	$temporaryfilename = _TempFile($szDrive & $szDir)
	$copysucess = FileCopy($filenames[$forcount], $temporaryfilename)
;~ 	Msgbox(0,$copysucess,$temporaryfilename)
	If $progresscheckboxstatus = $GUI_UNCHECKED Then
		$oggdecpid = Run('"' & $decoderexe & '" "' & $temporaryfilename & '"', @ScriptDir, @SW_HIDE, 4) ; & ' "' & @tempdir & "\" & $splitpath[3] & '.wav"' ,@scriptdir,@SW_SHOW )
	Else
		$oggdecpid = Run('"' & $decoderexe & '" "' & $temporaryfilename & '"', @ScriptDir, @SW_HIDE)
		GUICtrlSetData($progresslabel, "Decoding...")
	EndIf
	While ProcessExists($oggdecpid)
		If $progresscheckboxstatus = $GUI_UNCHECKED And $paused = False Then
			$readstreamarray = StringSplit(StderrRead($oggdecpid), @CR)
			If UBound($readstreamarray) > 2 Then
				If StringInStr($readstreamarray[2], "decoded.") Then
					$readstream = StringStripWS($readstreamarray[2], 3)
					$splitstream = StringSplit($readstream, "%")
					If UBound($splitstream) > 1 Then
;~ 				_ArrayDisplay($splitstream,"array")
						If UBound($splitstream) > 1 Then
							GUICtrlSetData($progresslabel, $splitstream[1] & "% done decoding...")
							GUICtrlSetData($progress, $splitstream[1])
							WinSetTitle($main, "", $splitstream[1] & "% done decoding")
						EndIf
					EndIf
				EndIf
			EndIf
		EndIf
;~ 		ConsoleWrite(StdoutRead($oggdecpid) & @CRLF)
		$msg = GUIGetMsg()
		Select
			Case $msg = $stopbutton
				$encodingcancelled = True
				ProcessClose($oggdecpid)
;~ 				While FileExists($splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav")
;~ 					FileDelete($splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav")
;~ 				WEnd
			Case $msg = $pausebutton
				If $paused = False Then
					GUICtrlSetData($pausebutton, "Resume")
					$paused = True
				Else
					GUICtrlSetData($pausebutton, "Pause")
					$paused = False
				EndIf
			Case $msg = $ontopcheckbox
				OnTopCheckbox()
			Case $msg = $GUI_EVENT_CLOSE
				$encodingcancelled = True
				ProcessClose($oggdecpid)
;~ 				While FileExists($splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav")
;~ 					FileDelete($splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav")
;~ 				WEnd
				Terminate()
		EndSelect
		If $paused = False Then SpinOggImage()
	WEnd
;~ Endif
	WinSetTitle($main, "", "MP3 <-> Ogg Vorbis Converter")
	GUICtrlSetData($fileprogresslabel, "")
	GUICtrlSetData($progresslabel, "")
	GUICtrlSetData($progress, 0)
;~ 	MsgBox(0, "Moving", $splitpath[1] & $splitpath[2] & $splitpath[3] & ".wav to " & @TempDir & "\" & $splitpath[3] & '.wav')
;~ 	FileMove($splitpath[1] & $splitpath[2] & $splitpath[3] & '.wav', @TempDir & "\" & $splitpath[3] & '.wav', 1)
	_PathSplit($temporaryfilename, $szDrive, $szDir, $szFName, $szExt)
	FileMove($szDrive & $szDir & $szFName & ".wav", @TempDir & "\" & $splitpath[3] & '.wav', 1)
	FileDelete($temporaryfilename)
	GUICtrlSetImage($oggpicture, $stroggpic[0])
EndFunc   ;==>OggDecode
Func OggEncode($filein, $fileout, $origextension)
	If $encodingcancelled = True Then Return 0
	$progresscheckboxstatus = GUICtrlRead($disableprogcheckbox)
	$iniread = False
	While $iniread = False
		If FileExists($inilocation) Then
			$oggencdir = IniRead($inilocation, "Computer", "OggEnc", "")
			If $oggencdir <> "" And FileExists($oggencdir) Then
				$iniread = True
				$vorbisquality = GUICtrlRead($oggvorbisqualityinput)
				$vorbisquality = "--quality " & $vorbisquality
				Local $szDrive, $szDir, $szFName, $szExt
				_PathSplit($filein, $szDrive, $szDir, $szFName, $szExt)
				GUICtrlSetData($fileprogresslabel, "Encoding: " & $szFName & ".ogg")
				If $progresscheckboxstatus = $GUI_UNCHECKED Then
					$oggencpid = Run('"' & $oggencdir & '" ' & $vorbisquality & ' "' & $filein & '"', @ScriptDir, @SW_HIDE, $STDERR_CHILD)
				Else
					$oggencpid = Run('"' & $oggencdir & '" ' & $vorbisquality & ' "' & $filein & '"', @ScriptDir, @SW_HIDE)
					GUICtrlSetData($progresslabel, "Encoding...")
				EndIf
				ProcessSetPriority($oggencpid, 0)
				$timestamp = TimerInit()
				$streamcounter = 0
				While ProcessExists($oggencpid)
					If $streamcounter > 100 And $progresscheckboxstatus = $GUI_UNCHECKED And $paused = False Then
						$readstream = StderrRead($oggencpid)
						#cs
							$splitstream = StringSplit($readstream,@CR)
							_ArrayDisplay($splitstream ,"")
							If UBound($splitstream) > 10 Then
							$position = StringInStr($splitstream[10] ,"%]")
;~ 							MsgBox(0,"first pos",$position)
							If $position > 0 Then
							msgbox(0,"splitstream[10]",$splitstream[10])
							$readstream2 = StringLeft($splitstream[10],$position - 1)
							MsgBox(0,"splitstream2",$readstream2)
							$position2 =StringInStr($readstream2,"[")
							MsgBox(0,"second pos",$position2)
							If $position2 > 0 Then
							$readstream3 = StringTrimRight($readstream2,$position2)
							Msgbox(0,"This is a number?",$readstream3)
							Endif
							EndIf
							EndIf
						#ce
						$position = StringInStr($readstream, "%]", 0, -1)
						If $position > 0 Then
							$readstream2 = StringLeft($readstream, $position - 1)
							$position2 = StringInStr($readstream2, "[ ", 0, -1)
							If $position2 > 0 Then
								$readstream3 = StringTrimLeft($readstream2, $position2)
;~ 								Msgbox(0,"This is a number?",$readstream3)
								GUICtrlSetData($progresslabel, "Ogg Encoding is " & Int($readstream3) & "% complete.")
								GUICtrlSetData($progress, $readstream3)
								WinSetTitle($main, "", Int($readstream3) & "% complete.")
							EndIf
						EndIf
;~ 						ConsoleWrite($readstream & @CR)
						$streamcounter = 0
					EndIf
;~ 					Sleep(10)
					$streamcounter = $streamcounter + 1
					If $paused = False Then SpinOggImage()
					$msg = GUIGetMsg()
					Select
						Case $msg = $stopbutton
							$encodingcancelled = True
							ProcessClose($oggencpid)
							While FileExists(@TempDir & "\" & $splitpath[3] & '.ogg')
								FileDelete(@TempDir & "\" & $splitpath[3] & '.ogg')
							WEnd
						Case $msg = $pausebutton
							If $paused = False Then
								GUICtrlSetData($pausebutton, "Resume")
								$paused = True
							Else
								GUICtrlSetData($pausebutton, "Pause")
								$paused = False
							EndIf
						Case $msg = $ontopcheckbox
							OnTopCheckbox()
						Case $msg = $GUI_EVENT_CLOSE
							$encodingcancelled = True
							ProcessClose($oggencpid)
							While FileExists(@TempDir & "\" & $splitpath[3] & '.ogg')
								FileDelete(@TempDir & "\" & $splitpath[3] & '.ogg')
							WEnd
							Terminate()
					EndSelect
				WEnd
				GUICtrlSetData($progresslabel, "Ogg Encoding is " & 100 & "% complete.")
				GUICtrlSetData($progress, 100)
				Sleep(50)
				WinSetTitle($main, "", "MP3 <-> Ogg Vorbis Converter")
				GUICtrlSetData($fileprogresslabel, "")
				GUICtrlSetData($progresslabel, "")
				GUICtrlSetData($progress, 0)
			Else
				GetSystemInfo()
			EndIf
		Else
			GetSystemInfo()
		EndIf
	WEnd
	GUICtrlSetImage($oggpicture, $stroggpic[0])
EndFunc   ;==>OggEncode
Func SpinOggImage()
	If TimerDiff($timestamp) > 100 Then
		GUICtrlSetImage($oggpicture, $stroggpic[$imageindexcounter])
		If $imageindexcounter < 11 Then
			$imageindexcounter = $imageindexcounter + 1
		Else
			$imageindexcounter = 0
		EndIf
		$timestamp = TimerInit()
	EndIf
EndFunc   ;==>SpinOggImage
Func OGGTagin($filein, $fileout, $origextension)
	If FileExists($fileout & ".ogg") Then
		#cs
			When using tag.exe, use the parameter --fromfile <filename>
			The total command should look like this:
			Tag.exe --fromfile <original filname>  filetosendtaginfoto
		#ce
;~ 					FileWriteLine("tag.bat",'"' & @ScriptDir & '\resource\ID3\Tag.exe" --fromfile "' & $fileout & $origextension & '" "' & $fileout & '.ogg"')
;~ 					FileWriteLine("tag.bat","pause")
;~ 					Run(@ScriptDir & "\tag.bat")
;~ 					msgbox(0,"tag",'"' & @ScriptDir & '\resouce\ID3\Tag.exe" --fromfile "' & $fileout & $origextension & '" "' & $fileout & '.ogg"')
		$pid = Run('"' & @ScriptDir & '\resource\ID3\Tag.exe" --fromfile "' & $fileout & $origextension & '" "' & $fileout & '.ogg"', @ScriptDir, @SW_HIDE)
		If @error Then
			MsgBox(0, "error", "Could not run tag.")
		EndIf
	Else
		If $encodingcancelled = False Then MsgBox(48, "Error!", "Could not create ogg file.")
	EndIf
EndFunc   ;==>OGGTagin
Func MP3QualityCombo()
;~ 	Msgbox(0,"","It has registered the press.")
	$readmp3combo = GUICtrlRead($mp3qualitycombo)
	Select
		Case $readmp3combo = 10
			GUICtrlSetData($mp3qualitylabel, "Approx. Bitrate 60 kbps")
		Case $readmp3combo = 20
			GUICtrlSetData($mp3qualitylabel, "Approx. Bitrate 84 kbps")
		Case $readmp3combo = 30
			GUICtrlSetData($mp3qualitylabel, "Approx. Bitrate 100 kbps")
		Case $readmp3combo = 40
			GUICtrlSetData($mp3qualitylabel, "Approx. Bitrate 118 kbps")
		Case $readmp3combo = 50
			GUICtrlSetData($mp3qualitylabel, "Approx. Bitrate 132 kbps")
		Case $readmp3combo = 60
			GUICtrlSetData($mp3qualitylabel, "Approx. Bitrate 152 kbps")
		Case $readmp3combo = 70
			GUICtrlSetData($mp3qualitylabel, "Approx. Bitrate 166 kbps")
		Case $readmp3combo = 80
			GUICtrlSetData($mp3qualitylabel, "Approx. Bitrate 190 kbps")
		Case $readmp3combo = 90
			GUICtrlSetData($mp3qualitylabel, "Approx. Bitrate 220 kbps")
		Case $readmp3combo = 100
			GUICtrlSetData($mp3qualitylabel, "Approx. Bitrate 240 kbps")
	EndSelect
	#cs
		CBR (constant bitrate, the default) options:
		-b <bitrate>    set the bitrate in kbps, default 128 kbps
		--cbr           enforce use of constant bitrate
		ABR options:
		--abr <bitrate> specify average bitrate desired (instead of quality)
		VBR options:
		-v              use variable bitrate (VBR) (--vbr-old)
		--vbr-old       use old variable bitrate (VBR) routine
		--vbr-new       use new variable bitrate (VBR) routine
		-V n            quality setting for VBR.  default n=4
		0=high quality,bigger files. 9=smaller files
		-b <bitrate>    specify minimum allowed bitrate, default  32 kbps
		-B <bitrate>    specify maximum allowed bitrate, default 320 kbps
		-F              strictly enforce the -b option, for use with players that
		do not support low bitrate mp3
		-t              disable writing LAME Tag
		-T              enable and force writing LAME Tag
	#ce
EndFunc   ;==>MP3QualityCombo
Func Checkforvalidbitrate()
	$readinput = GUICtrlRead($mp3bitratecombo)
	If $readinput > 320 Then GUICtrlSetData($mp3bitratecombo, 320)
EndFunc   ;==>Checkforvalidbitrate
Func CalculateNominalBitrate()
	$qcValue = GUICtrlRead($oggvorbisqualityinput)
	$qcValue = Number($qcValue)
;~ 	Msgbox(0,"Number", IsNumber($qcValue))
	If $qcValue > 10 Then
		$qcValue = 10
		GUICtrlSetData($oggvorbisqualityinput, 10.00)
		#cs;this is for older versions of ogg encoder.  only aoTuV beta3 and later has -2 quality preset
			ElseIf	$qcValue < - 1 Then
			$qcValue = -1
			GUICtrlSetData($oggvorbisqualityinput, -1.00)
		#ce
	ElseIf	$qcValue < - 2 Then
		$qcValue = -2
		GUICtrlSetData($oggvorbisqualityinput, -2.00)
	ElseIf $qcValue = "" Then
		$qcValue = 0
		GUICtrlSetData($oggvorbisqualityinput, 0)
	ElseIf $qcValue = 0 Then
		$qcValue = 0
		GUICtrlSetData($oggvorbisqualityinput, 0)
	EndIf
	Dim $approxBitrate
	;Exponential regression Equation for calculating bitrate
;~ 	$approxBitrate = 61.0188248 * 1.212853197 ^ $qcValue
	;Quartic Regression Equation for calculating bitrate
;~ 	$approxBitrate = Int(0.14863782051195*$qcValue^4-1.949373543108*$qcValue^3+7.698390151436*$qcValue^2+12.583114801949*$qcValue+54.604020979095)
	Select
		Case $qcValue = -2
			$approxBitrate = 32
		Case $qcValue = -1.5
			$approxBitrate = 40
		Case $qcValue = -1
			$approxBitrate = 48
		Case $qcValue = -.5
			$approxBitrate = 54.5
		Case $qcValue = 0
			$approxBitrate = 64
		Case $qcValue = .5
			$approxBitrate = 72
		Case $qcValue = 1
			$approxBitrate = 80
		Case $qcValue = 1.5
			$approxBitrate = 88
		Case $qcValue = 2
			$approxBitrate = 96
		Case $qcValue = 2.5
			$approxBitrate = 104
		Case $qcValue = 3
			$approxBitrate = 112
		Case $qcValue = 3.5
			$approxBitrate = 120
		Case $qcValue = 4
			$approxBitrate = 128
		Case $qcValue = 4.5
			$approxBitrate = 144
		Case $qcValue = 5
			$approxBitrate = 160
		Case $qcValue = 5.5
			$approxBitrate = 176
		Case $qcValue = 6
			$approxBitrate = 192
		Case $qcValue = 6.5
			$approxBitrate = 208
		Case $qcValue = 7.0
			$approxBitrate = 224
		Case $qcValue = 7.5
			$approxBitrate = 240
		Case $qcValue = 8
			$approxBitrate = 256
		Case $qcValue = 8.5
			$approxBitrate = 288
		Case $qcValue = 9
			$approxBitrate = 320
		Case $qcValue = 9.5
			$approxBitrate = 410
		Case $qcValue = 10
			$approxBitrate = 499
		Case $qcValue < - 1.5
			$approxBitrate = 40
		Case $qcValue < - 1
			$approxBitrate = 44
		Case Else
			$approxBitrate = Round(.15615878113278 * $qcValue ^ 4 - 2.1313550127011 * $qcValue ^ 3 + 8.958089827036 * $qcValue ^ 2 + 9.94005179155 * $qcValue + 55.448286006698, 1);a rough calculation based on dimensional analysis
	EndSelect
;~ 	$qcValue = $qcValue *10000
;~ 	Dim $approxBitrate
;~ If $qcValue < 0 Then
;~ 		$approxBitrate = 64000 - 1000*((($qcValue*-1/100)*19))
;~ 	elseif  $qcValue < 410 Then
;~ 		$approxBitrate = 1000 * (($qcValue/100)*16+64)
;~ 	elseif  $qcValue < 810  Then
;~ 		$approxBitrate = 1000 * (($qcValue/100)*32)
;~ 	elseif  $qcValue < 910  Then
;~ 		$approxBitrate = 1000 *((($qcValue/100)*32)+ _
;~ 						       ((($qcValue/100)-8)*32))
;~ 	else
;~ 		$approxBitrate = 1000 * (($qcValue/100)*32)+ _
;~ 								((($qcValue/100)-8)*32)+((($qcValue/100)-9)*116)
;~ Endif
;~ 	return $approxBitrate
	GUICtrlSetData($nominalbitratecaption, "Nominal Bitrate " & $approxBitrate & "kbps")
EndFunc   ;==>CalculateNominalBitrate
Func Checkvalidsampletobitrate()
	$readmp3sameplecombo = GUICtrlRead($mp3samplingratecombo)
;~ 	8|12|11.025|16|24|22.05|32|44.1|48
	If GUICtrlRead($lameconstantbitratecheck) = $GUI_CHECKED Then
		$readmp3bitratecombo = GUICtrlRead($mp3bitratecombo)
		Select
			Case $readmp3sameplecombo = 8
				GUICtrlSetData($mp3bitratecombo, "")
				GUICtrlSetData($mp3bitratecombo, "8|16|24|32|40|48|56|64|80|96|112|128|144|160")
				GUICtrlSetData($mp3bitratecombo, Mpeg2and2point5ComboCheck())
			Case $readmp3sameplecombo = 11.025
				GUICtrlSetData($mp3bitratecombo, "")
				GUICtrlSetData($mp3bitratecombo, "8|16|24|32|40|48|56|64|80|96|112|128|144|160")
				GUICtrlSetData($mp3bitratecombo, Mpeg2and2point5ComboCheck())
			Case $readmp3sameplecombo = 12
				GUICtrlSetData($mp3bitratecombo, "")
				GUICtrlSetData($mp3bitratecombo, "8|16|24|32|40|48|56|64|80|96|112|128|144|160")
				GUICtrlSetData($mp3bitratecombo, Mpeg2and2point5ComboCheck())
			Case $readmp3sameplecombo = 16
				GUICtrlSetData($mp3bitratecombo, "")
				GUICtrlSetData($mp3bitratecombo, "8|16|24|32|40|48|56|64|80|96|112|128|144|160")
				GUICtrlSetData($mp3bitratecombo, Mpeg2and2point5ComboCheck())
			Case $readmp3sameplecombo = 22.05
				GUICtrlSetData($mp3bitratecombo, "")
				GUICtrlSetData($mp3bitratecombo, "8|16|24|32|40|48|56|64|80|96|112|128|144|160")
				GUICtrlSetData($mp3bitratecombo, Mpeg2and2point5ComboCheck())
			Case $readmp3sameplecombo = 24
				GUICtrlSetData($mp3bitratecombo, "")
				GUICtrlSetData($mp3bitratecombo, "8|16|24|32|40|48|56|64|80|96|112|128|144|160")
				GUICtrlSetData($mp3bitratecombo, Mpeg2and2point5ComboCheck())
			Case $readmp3sameplecombo = 32
				GUICtrlSetData($mp3bitratecombo, "")
				GUICtrlSetData($mp3bitratecombo, "32|40|48|56|64|80|96|112|128|160|192|224|256|320")
				GUICtrlSetData($mp3bitratecombo, Mpeg1ComboCheck())
			Case $readmp3sameplecombo = 44.1
				GUICtrlSetData($mp3bitratecombo, "")
				GUICtrlSetData($mp3bitratecombo, "32|40|48|56|64|80|96|112|128|160|192|224|256|320")
				GUICtrlSetData($mp3bitratecombo, Mpeg1ComboCheck())
			Case $readmp3sameplecombo = 48
				GUICtrlSetData($mp3bitratecombo, "")
				GUICtrlSetData($mp3bitratecombo, "32|40|48|56|64|80|96|112|128|160|192|224|256|320")
				GUICtrlSetData($mp3bitratecombo, Mpeg1ComboCheck())
		EndSelect
	Else
		$readmp3bitratecombo = GUICtrlRead($mp3bitratecombo)
		GUICtrlSetData($mp3bitratecombo, "")
		$combostring = 0
		For $counter = 1 To 320
			$combostring &= "|" & $counter
		Next
		GUICtrlSetData($mp3bitratecombo, $combostring)
		GUICtrlSetData($mp3bitratecombo, $readmp3bitratecombo)
	EndIf
EndFunc   ;==>Checkvalidsampletobitrate
Func Mpeg2and2point5ComboCheck()
	Select
		Case $readmp3bitratecombo <= 8
			Return 8
		Case $readmp3bitratecombo <= 16
			Return 16
		Case $readmp3bitratecombo <= 24
			Return 24
		Case $readmp3bitratecombo <= 32
			Return 32
		Case $readmp3bitratecombo <= 40
			Return 40
		Case $readmp3bitratecombo <= 48
			Return 48
		Case $readmp3bitratecombo <= 56
			Return 56
		Case $readmp3bitratecombo <= 64
			Return 64
		Case $readmp3bitratecombo <= 80
			Return 80
		Case $readmp3bitratecombo <= 96
			Return 96
		Case $readmp3bitratecombo <= 112
			Return 112
		Case $readmp3bitratecombo <= 128
			Return 128
		Case $readmp3bitratecombo <= 144
			Return 144
		Case $readmp3bitratecombo <= 160
			Return 160
		Case $readmp3bitratecombo > 160
			Return 160
	EndSelect
EndFunc   ;==>Mpeg2and2point5ComboCheck
Func Mpeg1ComboCheck()
	Select
		Case $readmp3bitratecombo <= 32
			Return 32
		Case $readmp3bitratecombo <= 40
			Return 40
		Case $readmp3bitratecombo <= 48
			Return 48
		Case $readmp3bitratecombo <= 56
			Return 56
		Case $readmp3bitratecombo <= 64
			Return 64
		Case $readmp3bitratecombo <= 80
			Return 80
		Case $readmp3bitratecombo <= 96
			Return 96
		Case $readmp3bitratecombo <= 112
			Return 112
		Case $readmp3bitratecombo <= 128
			Return 128
		Case $readmp3bitratecombo <= 160
			Return 160
		Case $readmp3bitratecombo <= 192
			Return 192
		Case $readmp3bitratecombo <= 224
			Return 224
		Case $readmp3bitratecombo <= 256
			Return 256
		Case $readmp3bitratecombo <= 320
			Return 320
		Case $readmp3bitratecombo > 320
			Return 320
	EndSelect
EndFunc   ;==>Mpeg1ComboCheck
Func WriteINISettings()
	Checkvalidsampletobitrate()
	CalculateNominalBitrate()
	If GUICtrlRead($mp3qualityradio) = $GUI_CHECKED Then
		IniWrite($inilocation, "Settings", "MP3Radio", "Quality")
	Else
		IniWrite($inilocation, "Settings", "MP3Radio", "Bitrate")
	EndIf
	IniWrite($inilocation, "Settings", "QualitySetting", GUICtrlRead($mp3qualitycombo))
	IniWrite($inilocation, "Settings", "VBRMode", GUICtrlRead($mp3vbrmodecombo))
	IniWrite($inilocation, "Settings", "TargetBitrate", GUICtrlRead($mp3bitratecombo))
;~ 	If GUICtrlRead($lameconstantbitratecheck) = $GUI_CHECKED Then
;~ 		IniWrite($inilocation, "Settings", "CBR", $GUI_CHECKED)
	IniWrite($inilocation, "Settings", "CBR", GUICtrlRead($lameconstantbitratecheck))
;~ 	Else
;~ 		IniWrite($inilocation, "Settings", "CBR", $GUI_UNCHECKED)
;~ 	EndIf
;~ 	If GUICtrlRead($lamemonoencodingcheck) = $GUI_CHECKED Then
;~ 		IniWrite($inilocation, "Settings", "Mono", $GUI_CHECKED)
	IniWrite($inilocation, "Settings", "Mono", GUICtrlRead($lamemonoencodingcheck))
;~ 	Else
;~ 		IniWrite($inilocation, "Settings", "Mono", $GUI_UNCHECKED)
;~ 	EndIf
	IniWrite($inilocation, "Settings", "SamplingRate", GUICtrlRead($mp3samplingratecombo))
	#cs
		$oggstandardqualityradio
		InIWrite(
	#ce
	IniWrite($inilocation, "Settings", "VorbisQuality", GUICtrlRead($oggvorbisqualityinput))
	If GUICtrlRead($disableprogcheckbox) = $GUI_CHECKED Then
		IniWrite($inilocation, "Settings", "DisableStatus", $GUI_CHECKED)
	Else
		IniWrite($inilocation, "Settings", "DisableStatus", $GUI_UNCHECKED)
	EndIf
	IniWrite($inilocation, "Settings", "Overwritefiles", GUICtrlRead($overwritecheckbox))
	IniWrite($inilocation, "Settings", "OnTop", GUICtrlRead($ontopcheckbox))
EndFunc   ;==>WriteINISettings
Func INIReadSettings()
	;using a variable and then setting the state equal to the variable because it is easier to read
	$read = IniRead($inilocation, "Settings", "MP3Radio", "Quality")
	If $read = "Quality" Then
		GUICtrlSetState($mp3qualityradio, $GUI_CHECKED)
	Else
		GUICtrlSetState($mp3bitrateradio, $GUI_CHECKED)
	EndIf
	$read = IniRead($inilocation, "Settings", "QualitySetting", "50")
	GUICtrlSetData($mp3qualitycombo, $read)
	$read = IniRead($inilocation, "Settings", "VBRMode", "New Method")
	GUICtrlSetData($mp3vbrmodecombo, $read)
	$read = IniRead($inilocation, "Settings", "TargetBitrate", "128")
	GUICtrlSetData($mp3bitratecombo, $read)
	$read = IniRead($inilocation, "Settings", "CBR", $GUI_UNCHECKED)
	GUICtrlSetState($lameconstantbitratecheck, $read)
	$read = IniRead($inilocation, "Settings", "Mono", $GUI_UNCHECKED)
	GUICtrlSetState($lamemonoencodingcheck, $read)
	$read = IniRead($inilocation, "Settings", "SamplingRate", "44.1")
	GUICtrlSetData($mp3samplingratecombo, $read)
	$read = IniRead($inilocation, "Settings", "VorbisQuality", "6.00")
	GUICtrlSetData($oggvorbisqualityinput, $read)
	$read = IniRead($inilocation, "Settings", "DisableStatus", $GUI_UNCHECKED)
	GUICtrlSetState($disableprogcheckbox, $read)
	CalculateNominalBitrate()
	$read = IniRead($inilocation, "Settings", "Overwritefiles", $GUI_UNCHECKED)
	GUICtrlSetState($overwritecheckbox, $read)
	$read = IniRead($inilocation, "Settings", "OnTop", $GUI_CHECKED)
	GUICtrlSetState($ontopcheckbox, $read)
	OnTopCheckbox()
	$read = 0
EndFunc   ;==>INIReadSettings
Func Terminate()
	For $transcount = 255 To 0 Step - 1
		WinSetTrans($main, "", $transcount)
	Next
	WriteINISettings()
	Exit
EndFunc   ;==>Terminate
Func VerifyOverwrite($path)
	If FileExists($path) Then
		If GUICtrlRead($overwritecheckbox) = $GUI_CHECKED Then
			Return True
		Else
			MsgBox(48, "Error", 'The file "' & $path & '" already exists!', 10)
			Return False
		EndIf
	Else
		Return True
	EndIf
EndFunc   ;==>VerifyOverwrite
Func DisableControls()
	GUICtrlSetState($mp3bitratecombo, $GUI_DISABLE)
	GUICtrlSetState($mp3qualityradio, $GUI_DISABLE)
	GUICtrlSetState($mp3bitrateradio, $GUI_DISABLE)
	GUICtrlSetState($mp3qualitycombo, $GUI_DISABLE)
	GUICtrlSetState($mp3vbrmodecombo, $GUI_DISABLE)
	GUICtrlSetState($mp3bitratecombo, $GUI_DISABLE)
	GUICtrlSetState($lameconstantbitratecheck, $GUI_DISABLE)
	GUICtrlSetState($lamemonoencodingcheck, $GUI_DISABLE)
	GUICtrlSetState($mp3samplingratecombo, $GUI_DISABLE)
	GUICtrlSetState($oggstandardqualityradio, $GUI_DISABLE)
	GUICtrlSetState($oggvorbisqualityinput, $GUI_DISABLE)
	GUICtrlSetState($overwritecheckbox, $GUI_DISABLE)
	GUICtrlSetState($aboutbutton, $GUI_DISABLE)
EndFunc   ;==>DisableControls
Func EnableControls()
	GUICtrlSetState($mp3bitratecombo, $GUI_ENABLE)
	GUICtrlSetState($mp3qualityradio, $GUI_ENABLE)
	GUICtrlSetState($mp3bitrateradio, $GUI_ENABLE)
	GUICtrlSetState($mp3qualitycombo, $GUI_ENABLE)
	GUICtrlSetState($mp3vbrmodecombo, $GUI_ENABLE)
	GUICtrlSetState($mp3bitratecombo, $GUI_ENABLE)
	GUICtrlSetState($lameconstantbitratecheck, $GUI_ENABLE)
	GUICtrlSetState($lamemonoencodingcheck, $GUI_ENABLE)
	GUICtrlSetState($mp3samplingratecombo, $GUI_ENABLE)
	GUICtrlSetState($oggstandardqualityradio, $GUI_ENABLE)
	GUICtrlSetState($oggvorbisqualityinput, $GUI_ENABLE)
	GUICtrlSetState($overwritecheckbox, $GUI_ENABLE)
	GUICtrlSetState($aboutbutton, $GUI_ENABLE)
EndFunc   ;==>EnableControls
Func AboutBox()
	Opt("GUIOnEventMode", 0)
	GUISetState(@SW_DISABLE, $main)
	$aboutGUI = GUICreate("About MP3 to Ogg Vorbis Converter", 327, 195, (@DesktopWidth - 327) / 2, (@DesktopHeight - 195) / 2, $GUI_SS_DEFAULT_GUI, $WS_EX_TOPMOST) ;215, 148)
	GUICtrlCreateLabel("The Kandie Man" & @CRLF & "Uses optimized Lancer ogg encoders based on aoTuV b4b." & @CRLF & "Uses an optimized version of lame3.97b2." & @CRLF & "Uses CPUZ to detect machine instruction sets." & @CRLF & "Uses tag.exe to transfer tags.", 24, 22, 290, 68)
	GUICtrlCreateLabel("Copyright 2006 The Kandie Man", 24, 94, 221, 17)
;~ 	GUICtrlCreateLabel("Not responsible for damages done to your computer as a result of using this program.  User accepts full responsibilty.", 16, 120, 297, 28)
	$EULAlabel = GUICtrlCreateLabel("Click here to view the license agreement.", 16, 120, 297, 28)
	GUICtrlSetColor($EULAlabel, 0x0000FF)
	GUICtrlSetFont($EULAlabel, 9, 400, 4)
	GUICtrlCreateLabel("Current Version:", 16, 160, 79, 17)
	$Group1 = GUICtrlCreateGroup("MP3 <--> Ogg was created by:", 16, 8, 297, 110)
;~ 	GUICtrlCreateGroup("", -99, -99, 1, 1)
	$versionlabel = GUICtrlCreateLabel($version, 96, 160, 82, 17)
	$okbutton = GUICtrlCreateButton("&OK", 224, 160, 73, 25)
	GUICtrlSetState($okbutton, $GUI_DEFBUTTON)
	GUISetState(@SW_SHOW)
	While 1
		$msg = GUIGetMsg()
		Select
			Case $msg = $GUI_EVENT_CLOSE
				ExitLoop
			Case $msg = $EULAlabel
				Run(@ComSpec & " /c " & '"' & @ScriptDir & '\Ogg to MP3 License.txt"', "", @SW_HIDE)
			Case $msg = $okbutton
				ExitLoop
		EndSelect
	WEnd
	Opt("GUIOnEventMode", 1)
;~ 	GUISetState($mainGUI,@SW_ENABLE)
	GUISetState(@SW_ENABLE, $main)
	GUIDelete($aboutGUI)
EndFunc   ;==>AboutBox
Func OnTopCheckbox()
	If GUICtrlRead($ontopcheckbox) = $GUI_CHECKED Then
		WinSetOnTop($main, "", 1)
	Else
		WinSetOnTop($main, "", 0)
	EndIf
EndFunc   ;==>OnTopCheckbox